@@ -32,6 +32,6 @@ struct _user_data_t
   GstElement* sound_player;
 };
 
-void fill_profiles_list_store(GtkListStore* list_store);
+void fill_profiles_list_store(user_data_t* data);
 
 #endif
