@@ -42,6 +42,7 @@ struct _editor_data_t
   GtkListStore* systemsoundLevel;
 
   GtkWidget* autoAnswerButton;
+  GtkWidget* disableProximityCheck;
   GtkWidget* turnSpeakerOnButton;
 
   GtkWidget* vibratingCheckbutton;
@@ -289,6 +290,10 @@ set_profile_values(const gchar* profile_name, editor_data_t* data)
     hildon_check_button_set_active(HILDON_CHECK_BUTTON(data->autoAnswerButton), TRUE);
   else
     hildon_check_button_set_active(HILDON_CHECK_BUTTON(data->autoAnswerButton), FALSE);
+  if(data->profile_data->disable_proximity_check)
+    hildon_check_button_set_active(HILDON_CHECK_BUTTON(data->disableProximityCheck), TRUE);
+  else
+    hildon_check_button_set_active(HILDON_CHECK_BUTTON(data->disableProximityCheck), FALSE);
   if(data->profile_data->turn_speaker_on)
     hildon_check_button_set_active(HILDON_CHECK_BUTTON(data->turnSpeakerOnButton), TRUE);
   else
@@ -361,6 +366,7 @@ save_profile_values(const gchar* profile_name, editor_data_t* data)
 
   data->profile_data->vibrating_enabled = hildon_check_button_get_active(HILDON_CHECK_BUTTON(data->vibratingCheckbutton));
   data->profile_data->autoanswer = hildon_check_button_get_active(HILDON_CHECK_BUTTON(data->autoAnswerButton));
+  data->profile_data->disable_proximity_check = hildon_check_button_get_active(HILDON_CHECK_BUTTON(data->disableProximityCheck));
   data->profile_data->turn_speaker_on = hildon_check_button_get_active(HILDON_CHECK_BUTTON(data->turnSpeakerOnButton));
   profilesx_store_profile_data(profile_name, data->profile_data);
 }
@@ -786,6 +792,12 @@ init_sound_level_list_store(GtkListStore* list_store)
   gtk_list_store_set(list_store, &iter, 0, dgettext("osso-profiles", "profi_va_key_sounds_level2"), 1, 2, -1);
 }
 
+static void
+_enable_disable_proximity_check(HildonCheckButton* button, gpointer user_data)
+{
+  gtk_widget_set_sensitive(GTK_WIDGET(user_data), hildon_check_button_get_active(button));
+}
+
 static void 
 layout_dialog_widgets(const gchar* profile_name, editor_data_t* data, GtkWidget* dialog)
 {
@@ -826,6 +838,8 @@ layout_dialog_widgets(const gchar* profile_name, editor_data_t* data, GtkWidget*
     gtk_box_pack_start(GTK_BOX(content_area), data->keypadsoundLevelButton, TRUE, FALSE, 0);
     gtk_box_pack_start(GTK_BOX(content_area), data->touchscreensoundLevelButton, TRUE, FALSE, 0);
     gtk_box_pack_start(GTK_BOX(content_area), data->autoAnswerButton, TRUE, FALSE, 0);
+    gtk_box_pack_start(GTK_BOX(content_area), data->disableProximityCheck, TRUE, FALSE, 0);
+    g_signal_connect(data->autoAnswerButton, "toggled", G_CALLBACK(_enable_disable_proximity_check), data->disableProximityCheck);
     gtk_box_pack_start(GTK_BOX(content_area), data->turnSpeakerOnButton, TRUE, FALSE, 0);
     pannable_area = hildon_pannable_area_new();
     hildon_pannable_area_add_with_viewport(HILDON_PANNABLE_AREA(pannable_area), content_area);
@@ -879,6 +893,9 @@ init_editor_dialog_widgets(editor_data_t* data)
   data->autoAnswerButton = hildon_check_button_new(HILDON_SIZE_FINGER_HEIGHT);
   gtk_button_set_label(GTK_BUTTON(data->autoAnswerButton), "Autoanswer");
   hildon_check_button_set_active(HILDON_CHECK_BUTTON(data->autoAnswerButton), FALSE);
+  data->disableProximityCheck = hildon_check_button_new(HILDON_SIZE_FINGER_HEIGHT);
+  gtk_button_set_label(GTK_BUTTON(data->disableProximityCheck), "Disable Proximity Check");
+  hildon_check_button_set_active(HILDON_CHECK_BUTTON(data->disableProximityCheck), FALSE);
   data->turnSpeakerOnButton = hildon_check_button_new(HILDON_SIZE_FINGER_HEIGHT);
   gtk_button_set_label(GTK_BUTTON(data->turnSpeakerOnButton), 
 		       dgettext("rtcom-call-ui", "call_fi_call_handling_speaker"));
