@@ -64,6 +64,7 @@ struct _ProfilesxStatusPluginPrivate
   guint gconf_notify_handler;
   gboolean autoanswer;
   gboolean turn_speaker_on;
+  gboolean disable_proximity_check;
 };
 
 HD_DEFINE_PLUGIN_MODULE(ProfilesxStatusPlugin, profilesx_status_plugin, HD_TYPE_STATUS_MENU_ITEM);
@@ -265,7 +266,7 @@ static gboolean
 answer_call(gpointer user_data)
 {
   ProfilesxStatusPlugin* plugin = PROFILESX_STATUS_PLUGIN(user_data);
-  if(!is_proximity_covered())
+  if(plugin->priv->disable_proximity_check || !is_proximity_covered())
   {
     if(plugin->priv->dbus_system_conn)
     {
@@ -374,14 +375,17 @@ read_profile_gconf_options(ProfilesxStatusPlugin* plugin, const gchar* profile)
   g_assert(GCONF_IS_CLIENT(client));
   gchar* profile_name_key = gconf_escape_key(profile, -1);
   gchar* autoanswer_conf_key = g_strdup_printf("%s/%s/autoAnswer", GC_ROOT, profile_name_key);
+  gchar* disable_proximity_check_conf_key = g_strdup_printf("%s/%s/disableProximityCheck", GC_ROOT, profile_name_key);
   gchar* turnspeakeron_conf_key = g_strdup_printf("%s/%s/turnSpeakerOn", GC_ROOT, profile_name_key);
 
   plugin->priv->autoanswer = gconf_client_get_bool(client, autoanswer_conf_key, NULL);
+  plugin->priv->disable_proximity_check = gconf_client_get_bool(client, disable_proximity_check_conf_key, NULL);
   plugin->priv->turn_speaker_on = gconf_client_get_bool(client, turnspeakeron_conf_key, NULL);
 
   register_unregister_on_call(plugin);
   g_free(turnspeakeron_conf_key);
   g_free(autoanswer_conf_key);
+  g_free(disable_proximity_check_conf_key);
   g_free(profile_name_key);
   g_object_unref(client);
 }
@@ -608,6 +612,7 @@ profilesx_status_plugin_init(ProfilesxStatusPlugin* plugin)
 {
   plugin->priv = PROFILESX_STATUS_PLUGIN_GET_PRIVATE(plugin);
   plugin->priv->autoanswer = FALSE;
+  plugin->priv->disable_proximity_check = FALSE;
   plugin->priv->turn_speaker_on = FALSE;
   plugin->priv->gconf_notify_handler = 0;
   plugin->priv->dbus_system_conn = NULL;
